==> webkit2gtk_2.15.2.orig.tar.xz: webkitgtk-2.15.2/Source/WebCore/html/track/TextTrackCueList.h <==
/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(VIDEO_TRACK)

#include "TextTrackCue.h"
#include <wtf/PassRefPtr.h>
#include <wtf/RefCounted.h>
#include <wtf/Vector.h>

namespace WebCore {

class TextTrackCueList : public RefCounted<TextTrackCueList> {
public:
    static Ref<TextTrackCueList> create()
    {
        return adoptRef(*new TextTrackCueList);
    }

    ~TextTrackCueList() { }

    unsigned long length() const;
    unsigned long getCueIndex(TextTrackCue*) const;

    TextTrackCue* item(unsigned index) const;
    TextTrackCue* getCueById(const String&) const;
    TextTrackCueList* activeCues();

    bool add(PassRefPtr<TextTrackCue>);
    bool remove(TextTrackCue*);
    bool contains(TextTrackCue*) const;
    
    bool updateCueIndex(TextTrackCue*);

private:
    TextTrackCueList();
    bool add(PassRefPtr<TextTrackCue>, size_t, size_t);
    void clear();
    void invalidateCueIndexes(size_t);

    Vector<RefPtr<TextTrackCue>> m_list;
    RefPtr<TextTrackCueList> m_activeCues;
};

} // namespace WebCore

#endif // ENABLE(VIDEO_TRACK)

==> webkit2gtk_2.29.1.orig.tar.xz: webkitgtk-2.29.1/Source/WebCore/html/track/TextTrackCueList.h <==
/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 * Copyright (C) 2017-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(VIDEO_TRACK)

#include "TextTrackCue.h"

namespace WebCore {

class TextTrackCueList : public RefCounted<TextTrackCueList> {
public:
    static Ref<TextTrackCueList> create();

    unsigned length() const;
    TextTrackCue* item(unsigned index) const;
    TextTrackCue* getCueById(const String&) const;

    unsigned cueIndex(const TextTrackCue&) const;

    void add(Ref<TextTrackCue>&&);
    void remove(TextTrackCue&);
    void updateCueIndex(const TextTrackCue&);

    void clear();

    TextTrackCueList& activeCues();

private:
    TextTrackCueList() = default;

    Vector<RefPtr<TextTrackCue>> m_vector;
    RefPtr<TextTrackCueList> m_activeCues;
};

inline unsigned TextTrackCueList::length() const
{
    return m_vector.size();
}

} // namespace WebCore

#endif // ENABLE(VIDEO_TRACK)
